@@ -14,30 +14,34 @@ Map::Tube - A very simple perl interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
 
 Here is sample map
 
-    1 ----- 2 
-  /  \    /   \
- /    \  /     \
-0 ----  6 ----- 3
-\     /   \    /
- \   /     \  /
-   5  ---- 4 /
+    1 --------  2 
+   /  \       /  \
+  /    \     /    \
+ /      \   /      \
+0 ------  6 ------- 3
+ \      /   \      /
+  \    /     \    /
+   \  /       \  / 
+    5 -------- 4 
+   /
   /
- /
+ /  
 7
  \
   \
-   8 
+   \
+    8 
    
 which can be defined as below:
 
@@ -50,48 +54,113 @@ which can be defined as below:
   6 => [0,1,2,3,4,5],
   7 => [5,8],
   8 => [7],};
+  
+=head1 Example
 
+  use Map::Tube;
+  my $map = Map::Tube->new();
+  my @route = $map->get_shortest_route('Bond Street', 'Euston');
+  print "Shortest route from 'Bond Street' to 'Euston': " . join(" => ",@route) . "\n";  
+  my $map   = Map::Tube->new({from => 5, to => 2});
+  my @route = $map->get_shortest_route();
 
-    use Map::Tube;
-
-    my $map   = Map::Tube->new({from => 'Vauxhall', to => 'Euston'});
-	my @route = $map->get_shortest_route();
-	
-    ...
-	...
+  Output:
+  Shortest route from Bond Street to Euston: Bond Street => Oxford Circus => Warren Street => Euston
 
+=cut
+  
 =head1 CONSTRUCTOR
 
+The constructor expects an optional debug flag which is 0(false) by default.
+
 =cut
 
 sub new
 {
 	my $class = shift;
-	my $param = shift;
+	my $debug = shift;
 
 	my $self = {};
 	$self->{_node}    = Map::Tube::Node::init();
 	$self->{_element} = Map::Tube::Node::load_element();
 	$self->{_table}   = _initialize_table($self->{_node});
-	# TODO: Validate FROM and TO name.
-	$self->{_from} = $self->{_element}->{$param->{from}};
-	$self->{_to}   = $self->{_element}->{$param->{to}};
-	$self->{debug} = $param->{debug} || 0;
+	$self->{_debug}   = $debug || 0;
 	bless $self, $class;
 	return $self;
 }
 	
-=head1 SUBROUTINES/METHODS
+=head1 METHODS
+
+=head2 get_shortest_route()
+
+This method accepts FROM and TO node name. It is case sensitive at the moment. However I would make it case-insensitive very soon.
+It returns back the node sequence from FROM to TO.
+
+=cut
+
+sub get_shortest_route
+{
+	my $self = shift;
+	my $from = shift;
+	my $to   = shift;
+	croak("ERROR: Either FROM/TO node is undefined.\n") 
+		unless (defined($from) && defined($to));
+	croak("ERROR: Received invalid FROM node $from.\n")
+		unless exists $self->{_element}->{$from};
+	croak("ERROR: Received invalid TO node $to.\n")
+		unless exists $self->{_element}->{$to};
+		
+	my ($table, @routes);
+	$from = $self->{_element}->{$from};
+	$to   = $self->{_element}->{$to};
+	
+	$self->_process_node($from);
+	$table = $self->{_table};
+	while(defined($from) && defined($to) && ($from ne $to))
+	{
+		push @routes, $self->_get_name($to);
+		$to = $table->{$to}->{path};
+		sleep 1 if $self->{_debug};
+	}
+	push @routes, $self->_get_name($from);
+	return reverse(@routes);
+}
+
+
+=head2 show_map_chart()
+
+This method takes no parameter. It prints map chart to STDOUT generated while looking for shortest route. It has three columns by 
+the title "N" - Node Code, "P" - Path to here and "L" - Length to reach "N" from "P". At the moment it dumps node code used internally,
+however, I would change that to dump real node name instead soon.
+
+=cut
+
+sub show_map_chart
+{
+	my $self  = shift;
+	my $table = $self->{_table};
+	print " N  -  P  -  L\n----------------\n";
+	foreach (sort keys %{$table})
+	{
+		my $path   = (defined($table->{$_}->{path}))?($table->{$_}->{path}):('');
+		my $length = (defined($table->{$_}->{length}))?($table->{$_}->{length}):('');
+		print {*STDOUT} sprintf("%3s - %3s - %3s\n",$_,$path,$length);
+	}
+	print "-----------------\n\n";
+}
 
 =head2 _process_node
 
+This is the core method of the module, which takes FROM node code only. This assumes all the node definitions are defined and
+map chart has been initialized.
+
 =cut
 
 sub _process_node
 {
 	my $self  = shift;
+	my $from  = shift;
 	my $node  = $self->{_node};
-	my $from  = $self->{_from};
 	my $table = $self->{_table};
 
 	my (@queue, $index, $continue);
@@ -109,8 +178,8 @@ sub _process_node
 				$table->{$_}->{length} = $table->{$from}->{length}+1;
 				$table->{$_}->{path}   = $from;
 				push @queue, $_;
-				print "Pushing to queue [$_]\n" if $self->{debug};
-				sleep 1 if $self->{debug};
+				print "Pushing to queue [$_]\n" if $self->{_debug};
+				sleep 1 if $self->{_debug};
 				$continue = 1;
 			}
 		}
@@ -123,6 +192,9 @@ sub _process_node
 
 =head2 _initialize_table()
 
+This is an internal method and it simply initialize the map chart. It takes nodes definition as reference to a hash and return 
+the table, which is also reference to a hash.
+
 =cut
 
 sub _initialize_table
@@ -137,50 +209,11 @@ sub _initialize_table
 	return $table;
 }
 
-=head2 show_map_chart()
-
-=cut
-
-sub show_map_chart
-{
-	my $self  = shift;
-	my $table = $self->{_table};
-	print " N  -  P  -  L\n----------------\n";
-	foreach (sort keys %{$table})
-	{
-		my $path   = (defined($table->{$_}->{path}))?($table->{$_}->{path}):('');
-		my $length = (defined($table->{$_}->{length}))?($table->{$_}->{length}):('');
-		print sprintf("%3s - %3s - %3s\n",$_,$path,$length);
-	}
-	print "-----------------\n\n";
-}
-
-=head2 get_shortest_route()
-
-=cut
-
-sub get_shortest_route
-{
-	my $self  = shift;
-	
-	$self->_process_node();
-	my $table = $self->{_table};
-	my $from  = $self->{_from};
-	my $to    = $self->{_to};
-
-	my @routes;
-	while($from ne $to)
-	{
-		push @routes, $self->_get_name($to);
-		$to = $table->{$to}->{path};
-		sleep 1 if $self->{debug};
-	}
-	push @routes, $self->_get_name($from);
-	return reverse(@routes);
-}
-
 =head2 _get_name()
 
+This is an internal method and not exposed to the outside world. It takes node code and gives us full name of the node.
+It is only called from the method get_shortest_route().
+
 =cut
 
 sub _get_name
@@ -197,7 +230,7 @@ sub _get_name
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad S Anwar, C<< <mohammad.anwar@yahoo.com> >>
 
 =head1 BUGS
 
